==> pgbackrest_2.01.orig.tar.gz: pgbackrest-release-2.01/test/src/module/common/timeTest.c <==
/***********************************************************************************************************************************
Test Time Management
***********************************************************************************************************************************/

/***********************************************************************************************************************************
Test Run
***********************************************************************************************************************************/
void
testRun()
{
    // *****************************************************************************************************************************
    if (testBegin("timeUSec()"))
    {
        // Make sure the time returned is between 2017 and 2100
        TEST_RESULT_BOOL(timeUSec() > (TimeUSec)1483228800000000, true, "lower range check");
        TEST_RESULT_BOOL(timeUSec() < (TimeUSec)4102444800000000, true, "upper range check");
    }

    // *****************************************************************************************************************************
    if (testBegin("sleepUSec()"))
    {
        // Sleep and measure time slept
        TimeUSec begin = timeUSec();
        sleepUSec(1400000);
        TimeUSec end = timeUSec();

        // Check bounds for time slept (within a range of .1 seconds)
        TEST_RESULT_BOOL(end - begin > (TimeUSec)1400000, true, "lower range check");
        TEST_RESULT_BOOL(end - begin < (TimeUSec)1500000, true, "upper range check");
    }
}

==> pgbackrest_2.02.orig.tar.gz: pgbackrest-release-2.02/test/src/module/common/timeTest.c <==
/***********************************************************************************************************************************
Test Time Management
***********************************************************************************************************************************/

/***********************************************************************************************************************************
Test Run
***********************************************************************************************************************************/
void
testRun()
{
    // *****************************************************************************************************************************
    if (testBegin("timeMSec()"))
    {
        // Make sure the time returned is between 2017 and 2100
        TEST_RESULT_BOOL(timeMSec() > (TimeMSec)1483228800000, true, "lower range check");
        TEST_RESULT_BOOL(timeMSec() < (TimeMSec)4102444800000, true, "upper range check");
    }

    // *****************************************************************************************************************************
    if (testBegin("sleepMSec()"))
    {
        // Sleep and measure time slept
        TimeMSec begin = timeMSec();
        sleepMSec(1400);
        TimeMSec end = timeMSec();

        // Check bounds for time slept (within a range of .1 seconds)
        TEST_RESULT_BOOL(end - begin >= (TimeMSec)1400, true, "lower range check");
        TEST_RESULT_BOOL(end - begin < (TimeMSec)1500, true, "upper range check");
    }
}
